@@ -194,12 +194,9 @@ protected:
         align_positionV
     };
     KoFilter::ConversionStatus read_align(alignCaller caller);
-
     KoFilter::ConversionStatus read_pict();
-
     KoFilter::ConversionStatus read_sdt();
     KoFilter::ConversionStatus read_sdtContent();
-
     KoFilter::ConversionStatus read_inline();
     KoFilter::ConversionStatus read_extent();
     KoFilter::ConversionStatus read_docPr();
@@ -207,10 +204,14 @@ protected:
     KoFilter::ConversionStatus read_positionH();
     KoFilter::ConversionStatus read_positionV();
     KoFilter::ConversionStatus read_posOffset(posOffsetCaller caller);
+    KoFilter::ConversionStatus read_wrapPolygon();
     KoFilter::ConversionStatus read_wrapSquare();
     KoFilter::ConversionStatus read_wrapTight();
     KoFilter::ConversionStatus read_wrapThrough();
 
+    //! Read wrapping related attributes.
+    void readWrapAttrs();
+
     bool m_createSectionStyle;
     QString m_currentSectionStyleName;
     bool m_createSectionToNext;
