@@ -38,8 +38,8 @@
 #include <kconfig.h>
 #include <kglobalsettings.h>
 
-#include <kexidb/tableschema.h>
-#include <kexidb/utils.h>
+#include <db/tableschema.h>
+#include <db/utils.h>
 #include <kexidragobjects.h>
 #include "KexiRelationsTableContainer_p.h"
 #include "KexiRelationsScrollArea.h"
